@@ -8,18 +8,21 @@ from graphgallery.utils.conversion import (check_and_convert, sparse_adj_to_edge
 from graphgallery.utils.data_utils import normalize_adj, normalize_x, Bunch, sample_mask
 from graphgallery.config import set_epsilon, set_floatx, set_intx, epsilon, floatx, intx
 from graphgallery.utils.tensor_utils import normalize_adj_tensor, normalize_edge_tensor
-from graphgallery.utils.shape_utils import repeat
+from graphgallery.utils.shape import repeat
 from graphgallery.utils.type_check import *
 from graphgallery.utils.tqdm import tqdm
 from graphgallery.utils.gdc import GDC
 from graphgallery.utils.degree import degree_mixing_matrix, degree_assortativity_coefficient
 from graphgallery.utils.context_manager import nullcontext
+from graphgallery.utils.misc import set_memory_growth
+from graphgallery.utils.ego import ego_graph
 
 from graphgallery import nn
 from graphgallery import utils
 from graphgallery import sequence
+from graphgallery import data
 
 
-__version__ = '0.1.7'
+__version__ = '0.1.11'
 
 __all__ = ['graphgallery', 'nn', 'utils', 'sequence', 'data', '__version__']
