@@ -2,6 +2,7 @@ import os
 import random
 import logging
 
+import os.path as osp
 import numpy as np
 import tensorflow as tf
 import scipy.sparse as sp
@@ -9,6 +10,8 @@ import scipy.sparse as sp
 from graphgallery import config, check_and_convert, asintarr, Bunch
 from graphgallery.utils.type_check import is_list_like
 from graphgallery.utils.misc import print_table
+from graphgallery.data.utils import makedirs
+
 
 
 class BaseModel:
@@ -42,7 +45,7 @@ class BaseModel:
 
     """
 
-    def __init__(self, adj, x, labels=None, device="CPU:0", seed=None, name=None, **kwargs):
+    def __init__(self, adj, x=None, labels=None, device="CPU:0", seed=None, name=None, **kwargs):
 
         if seed is not None:
             np.random.seed(seed)
@@ -67,7 +70,7 @@ class BaseModel:
                 "Invalid keyword argument(s) in `__init__`: %s" % (unknown_kwargs,))
 
         # check the input adj and x, and convert them to appropriate forms
-        self.n_nodes, self.n_features = x.shape
+        self.n_nodes = adj.shape[0]
 
         self.is_adj_sparse = is_adj_sparse
         self.is_x_sparse = is_x_sparse
@@ -78,6 +81,11 @@ class BaseModel:
             self.n_classes = np.max(labels) + 1
         else:
             self.n_classes = None
+            
+        if x is not None:
+            self.n_features = x.shape[1]
+        else:
+            self.n_features = None
 
         self.seed = seed
         self.device = device
@@ -97,8 +105,8 @@ class BaseModel:
         self.__sparse = is_adj_sparse
 
         # log path
-        self.weight_dir = "./weight"
-        self.weight_path = f"{self.weight_dir}/{name}_weights"
+        self.weight_dir = osp.expanduser(osp.normpath("/tmp/weight"))
+        self.weight_path = osp.join(self.weight_dir, f"{name}_weights")
 
         # data types, default: `float32` and `int64`
         self.floatx = config.floatx()
@@ -113,22 +121,7 @@ class BaseModel:
         self.model_paras = Bunch(name=name)
         self.train_paras = Bunch(name=name)
         
-    @property
-    def custom_objects(self):
-        return self.__custom_objects
-    
-    @custom_objects.setter
-    def custom_objects(self, value):
-        assert isinstance(value, dict)
-        self.__custom_objects = value
-        
-    @property
-    def sparse(self):
-        return self.__sparse
-    
-    @sparse.setter
-    def sparse(self, value):
-        self.__sparse = value
+
 
     def _check_inputs(self, adj, x):
         """Check the input adj and x and make sure they are legal forms of input.
@@ -157,36 +150,24 @@ class BaseModel:
             adj_shape = adj[0].shape
         else:
             adj_shape = adj.shape
+        
+        if x is not None:
+            x_shape = x.shape
 
-        x_shape = x.shape
+            if adj_shape[0] != x_shape[0]:
+                raise RuntimeError(f"The first dimension of adjacency matrix and feature matrix should be equal.")
 
-        if adj_shape[0] != x_shape[0]:
-            raise RuntimeError(f"The first dimension of adjacency matrix and feature matrix should be equal.")
+            if len(adj_shape) != len(x_shape) != 2:
+                raise RuntimeError(f"The adjacency matrix and feature matrix should have the SAME dimensions 2.")
 
-        if len(adj_shape) != len(x_shape) != 2:
-            raise RuntimeError(f"The adjacency matrix and feature matrix should have the SAME dimensions 2.")
-
-        if adj_shape[0] != adj_shape[1]:
-            raise RuntimeError(f"The adjacency matrix should be N by N square matrix.")
+            if adj_shape[0] != adj_shape[1]:
+                raise RuntimeError(f"The adjacency matrix should be N by N square matrix.")
         return adj, x
 
-    @property
-    def model(self):
-        return self.__model
-
-    @model.setter
-    def model(self, m):
-        # Back up
-        if isinstance(m, tf.keras.Model):
-            self.backup = tf.identity_n(m.weights)
-        # assert m is None or isinstance(m, tf.keras.Model)
-        self.__model = m
-    
-
     def save(self, path=None, as_model=False):
-        if not os.path.exists(self.weight_dir):
-            os.makedirs(self.weight_dir)
-            logging.log(logging.WARNING, f"Mkdir {self.weight_dir}")
+        if not osp.exists(self.weight_dir):
+            makedirs(self.weight_dir)
+            logging.log(logging.WARNING, f"Make Directory in {self.weight_dir}")
 
         if path is None:
             path = self.weight_path
@@ -206,6 +187,7 @@ class BaseModel:
     def load(self, path=None, as_model=False):
         if not path:
             path = self.weight_path
+            
         if not path.endswith('.h5'):
             path += '.h5'
         if as_model:
@@ -238,3 +220,42 @@ class BaseModel:
             paras = self.paras
             
         print_table(paras)
+        
+ 
+    def __getattr__(self, attr):
+    ################### TODO: This may cause ERROR #############
+        try:
+            return self.__dict__[attr]
+        except KeyError:
+            if hasattr(self.model, attr):
+                return getattr(self.model, attr)
+            raise AttributeError(f"'{self.name}' and '{self.name}.model' objects have no attribute '{attr}'")
+        
+    @property
+    def model(self):
+        return self.__model
+    
+    @model.setter
+    def model(self, m):
+        # Back up
+        if isinstance(m, tf.keras.Model) and m.weights:
+            self.backup = tf.identity_n(m.weights)
+        # assert m is None or isinstance(m, tf.keras.Model)
+        self.__model = m
+        
+    @property
+    def custom_objects(self):
+        return self.__custom_objects
+    
+    @custom_objects.setter
+    def custom_objects(self, value):
+        assert isinstance(value, dict)
+        self.__custom_objects = value
+        
+    @property
+    def sparse(self):
+        return self.__sparse
+    
+    @sparse.setter
+    def sparse(self, value):
+        self.__sparse = value
\ No newline at end of file
