@@ -10,8 +10,8 @@ from tensorflow.keras.losses import SparseCategoricalCrossentropy
 from graphgallery.nn.layers import GraphConvolution, SparseConversion
 from graphgallery.nn.models import SemiSupervisedModel
 from graphgallery.sequence import ClusterMiniBatchSequence
-from graphgallery.utils.graph_utils import partition_graph
-from graphgallery.utils.shape_utils import set_equal_in_length
+from graphgallery.utils.graph import partition_graph
+from graphgallery.utils.shape import set_equal_in_length
 from graphgallery import Bunch, sample_mask, normalize_x, normalize_adj, astensors, asintarr, sparse_adj_to_edges
 
 
@@ -40,8 +40,9 @@ class ClusterGCN(SemiSupervisedModel):
                 the graph will be converted by `adj` automatically, but it will comsum lots
                 of time. (default :obj: `None`)
             n_clusters (Potitive integer):
-                The number of clusters that the graph being seperated, if not specified (`None`),
-                it will be set to the number of classes automatically. (default :obj: `None`).
+                The number of clusters that the graph being seperated, 
+                if not specified (`None`), it will be set to the number 
+                of classes automatically. (default :obj: `None`).
             norm_adj (Float scalar, optional):
                 The normalize rate for adjacency matrix `adj`. (default: :obj:`-0.5`,
                 i.e., math:: \hat{A} = D^{-\frac{1}{2}} A D^{-\frac{1}{2}})
