@@ -1,4 +1,5 @@
 import os
+import logging
 import warnings
 import numpy as np
 import tensorflow as tf
@@ -8,6 +9,7 @@ from tensorflow.keras import backend as K
 from tensorflow.keras.utils import Sequence
 from tensorflow.python.keras import callbacks as callbacks_module
 from tensorflow.keras.callbacks import EarlyStopping, ModelCheckpoint
+from tensorflow.keras.callbacks import History as tf_History
 
 from graphgallery.nn.models import BaseModel
 from graphgallery.utils.history import History
@@ -107,7 +109,7 @@ class SemiSupervisedModel(BaseModel):
         """
         raise NotImplementedError
 
-    def train(self, idx_train, idx_val=None,
+    def train_v1(self, idx_train, idx_val=None,
               epochs=200, early_stopping=None,
               verbose=False, save_best=True, weight_path=None, as_model=False,
               monitor='val_acc', early_stop_metric='val_loss'):
@@ -176,21 +178,24 @@ class SemiSupervisedModel(BaseModel):
             train_data = self.train_sequence(idx_train)
             self.idx_train = idx_train
 
-        validation = idx_val
+        validation = idx_val is not None
 
-        if validation is not None:
+        if validation:
             if isinstance(idx_val, Sequence):
                 val_data = idx_val
             else:
                 idx_val = asintarr(idx_val)
                 val_data = self.test_sequence(idx_val)
                 self.idx_val = idx_val
+        else:
+            monitor = 'acc' if monitor[:3] == 'val' else monitor
 
         history = History(monitor_metric=monitor,
                           early_stop_metric=early_stop_metric)
 
         if not weight_path:
             weight_path = self.weight_path
+        
         if not weight_path.endswith('.h5'):
             weight_path += '.h5'
 
@@ -215,17 +220,17 @@ class SemiSupervisedModel(BaseModel):
             if self.do_before_train:
                 self.do_before_train()
 
-            loss, accuracy = self.do_forward(train_data)
+            loss, accuracy = self.train_step(train_data)
             train_data.on_epoch_end()
 
             history.add_results(loss, 'loss')
             history.add_results(accuracy, 'acc')
 
-            if validation is not None:
+            if validation:
                 if self.do_before_validation:
                     self.do_before_validation()
 
-                val_loss, val_accuracy = self.do_forward(val_data, training=False)
+                val_loss, val_accuracy = self.test_step(val_data)
 
                 history.add_results(val_loss, 'val_loss')
                 history.add_results(val_accuracy, 'val_acc')
@@ -246,7 +251,7 @@ class SemiSupervisedModel(BaseModel):
 
             if verbose:
                 msg = f'loss {loss:.2f}, acc {accuracy:.2%}'
-                if validation is not None:
+                if validation:
                     msg += f', val_loss {val_loss:.2f}, val_acc {val_accuracy:.2%}'
                 pbar.set_description(msg)
 
@@ -256,6 +261,188 @@ class SemiSupervisedModel(BaseModel):
 
         return history
 
+    def train(self, idx_train, idx_val=None,
+                 epochs=200, early_stopping=None,
+                 verbose=False, save_best=True, weight_path=None, as_model=False,
+                 monitor='val_acc', early_stop_metric='val_loss', callbacks=None, **kwargs):
+        """
+            Train the model for the input `idx_train` of nodes or `sequence`.
+
+        Note:
+        ----------
+            You must compile your model before training/testing/predicting. Use `model.build()`.
+
+        Arguments:
+        ----------
+            idx_train: Numpy array-like, `list`, Integer scalar or `graphgallery.NodeSequence`
+                the index of nodes (or sequence) that will be used during training.    
+            idx_val: Numpy array-like, `list`, Integer scalar or `graphgallery.NodeSequence`, optional
+                the index of nodes (or sequence) that will be used for validation. 
+                (default :obj: `None`, i.e., do not use validation during training)
+            epochs: Postive integer
+                The number of epochs of training.(default :obj: `200`)
+            early_stopping: Postive integer or None
+                The number of early stopping patience during training. (default :obj: `None`, 
+                i.e., do not use early stopping during training)
+            verbose: Boolean
+                Whether to show the training details. (default :obj: `None`)
+            save_best: Boolean
+                Whether to save the best weights (accuracy of loss depend on `monitor`) 
+                of training or validation (depend on `validation` is `False` or `True`). 
+                (default :bool: `True`)
+            weight_path: String or None
+                The path of saved weights/model. (default :obj: `None`, i.e., 
+                `./log/{self.name}_weights`)
+            as_model: Boolean
+                Whether to save the whole model or weights only, if `True`, the `self.custom_objects`
+                must be speficied if you are using customized `layer` or `loss` and so on.
+            monitor: String
+                One of (val_loss, val_acc, loss, acc), it determines which metric will be
+                used for `save_best`. (default :obj: `val_acc`)
+            early_stop_metric: String
+                One of (val_loss, val_acc, loss, acc), it determines which metric will be 
+                used for early stopping. (default :obj: `val_loss`)
+            callbacks: tensorflow.keras.callbacks. (default :obj: `None`)
+            kwargs: other keyword arguments.
+
+        Return:
+        ----------
+            A `tf.keras.callbacks.History` object. Its `History.history` attribute is
+            a record of training loss values and metrics values
+            at successive epochs, as well as validation loss values
+            and validation metrics values (if applicable).
+
+        """
+        ############# Record paras ###########
+        local_paras = locals()
+        local_paras.pop('self')
+        local_paras.pop('idx_train')
+        local_paras.pop('idx_val')
+        paras = Bunch(**local_paras)
+        ######################################
+        model = self.model
+        model.stop_training = False
+        
+        # Check if model has been built
+        if model is None:
+            raise RuntimeError('You must compile your model before training/testing/predicting. Use `model.build()`.')
+
+        if isinstance(idx_train, Sequence):
+            train_data = idx_train
+        else:
+            idx_train = asintarr(idx_train)
+            train_data = self.train_sequence(idx_train)
+            self.idx_train = idx_train
+
+        validation = idx_val is not None
+
+        if validation:
+            if isinstance(idx_val, Sequence):
+                val_data = idx_val
+            else:
+                idx_val = asintarr(idx_val)
+                val_data = self.test_sequence(idx_val)
+                self.idx_val = idx_val
+        else:
+            monitor = 'acc' if monitor[:3] == 'val' else monitor
+
+
+
+        if not isinstance(callbacks, callbacks_module.CallbackList):
+            callbacks = callbacks_module.CallbackList(callbacks)
+            
+        his = tf_History()
+        callbacks.append(his) 
+        
+        if early_stopping:
+            es_callback = EarlyStopping(monitor=early_stop_metric,
+                                        patience=early_stopping,
+                                        mode='auto',
+                                        verbose=kwargs.pop('es_verbose', 1))
+            callbacks.append(es_callback)
+
+        if save_best:
+            if not weight_path:
+                if not os.path.exists(self.weight_dir):
+                    os.makedirs(self.weight_dir)
+                    logging.log(logging.WARNING, f"Make Directory in {self.weight_dir}")
+                    
+                weight_path = self.weight_path
+
+            if not weight_path.endswith('.h5'):
+                weight_path += '.h5'
+                
+
+            mc_callback = ModelCheckpoint(weight_path,
+                                          monitor=monitor,
+                                          save_best_only=True,
+                                          save_weights_only=not as_model,
+                                          verbose=0)
+            callbacks.append(mc_callback)
+        callbacks.set_model(model)
+
+        ############# Record paras ###########
+        paras.update(Bunch(weight_path=weight_path))
+        # update all parameters
+        self.paras.update(paras)
+        self.train_paras.update(paras)
+        ######################################
+
+        # leave it blank for the future
+        allowed_kwargs = set([])
+        unknown_kwargs = set(kwargs.keys()) - allowed_kwargs
+        if unknown_kwargs:
+            raise TypeError(
+                "Invalid keyword argument(s) in `__init__`: %s" % (unknown_kwargs,))
+
+        callbacks.on_train_begin()
+        
+        if verbose:
+            pbar = tqdm(range(1, epochs+1))
+        else:
+            pbar = range(1, epochs+1)
+            
+        for epoch in pbar:
+            callbacks.on_epoch_begin(epoch)
+
+            if self.do_before_train:
+                self.do_before_train()
+
+            callbacks.on_train_batch_begin(0)
+            loss, accuracy = self.train_step(train_data)
+            train_data.on_epoch_end()
+
+            training_logs = {'loss': loss, 'acc': accuracy}
+            callbacks.on_train_batch_end(0, training_logs)
+
+            if validation:
+                if self.do_before_validation:
+                    self.do_before_validation()
+
+                val_loss, val_accuracy = self.test_step(val_data)
+                training_logs.update({'val_loss': val_loss, 'val_acc': val_accuracy})
+
+            callbacks.on_epoch_end(epoch, training_logs)
+            
+            if verbose:
+                msg = "<"
+                for key, val in training_logs.items():
+                    msg += f"{key.title()} = {val:.4f} "
+                msg += ">"
+                pbar.set_description(msg)            
+
+            if model.stop_training:
+                break
+
+        callbacks.on_train_end()
+
+        if save_best:
+            self.load(weight_path, as_model=as_model)
+            if os.path.exists(weight_path):
+                os.remove(weight_path)
+
+        return his
+
     def train_v2(self, idx_train, idx_val=None,
                  epochs=200, early_stopping=None,
                  verbose=False, save_best=True, weight_path=None, as_model=False,
@@ -330,15 +517,17 @@ class SemiSupervisedModel(BaseModel):
             train_data = self.train_sequence(idx_train)
             self.idx_train = idx_train
 
-        validation = idx_val
+        validation = idx_val is not None
 
-        if validation is not None:
+        if validation:
             if isinstance(idx_val, Sequence):
                 val_data = idx_val
             else:
                 idx_val = asintarr(idx_val)
                 val_data = self.test_sequence(idx_val)
                 self.idx_val = idx_val
+        else:
+            monitor = 'acc' if monitor[:3] == 'val' else monitor
 
         model = self.model
         if not isinstance(callbacks, callbacks_module.CallbackList):
@@ -356,6 +545,9 @@ class SemiSupervisedModel(BaseModel):
 
         if save_best:
             if not weight_path:
+                if not os.path.exists(self.weight_dir):
+                    os.makedirs(self.weight_dir)
+                    logging.log(logging.WARNING, f"Make Directory in {self.weight_dir}")                
                 weight_path = self.weight_path
 
             if not weight_path.endswith('.h5'):
@@ -392,17 +584,17 @@ class SemiSupervisedModel(BaseModel):
                 self.do_before_train()
 
             callbacks.on_train_batch_begin(0)
-            loss, accuracy = self.do_forward(train_data)
+            loss, accuracy = self.train_step(train_data)
             train_data.on_epoch_end()
 
             training_logs = {'loss': loss, 'acc': accuracy}
             callbacks.on_train_batch_end(0, training_logs)
 
-            if validation is not None:
+            if validation:
                 if self.do_before_validation:
                     self.do_before_validation()
 
-                val_loss, val_accuracy = self.do_forward(val_data, training=False)
+                val_loss, val_accuracy = self.test_step(val_data)
                 training_logs.update({'val_loss': val_loss, 'val_acc': val_accuracy})
 
             callbacks.on_epoch_end(epoch, training_logs)
@@ -418,7 +610,7 @@ class SemiSupervisedModel(BaseModel):
                 os.remove(weight_path)
 
         return model.history
-
+    
     def test(self, index, **kwargs):
         """
             Test the output accuracy for the `index` of nodes or `sequence`.
@@ -458,16 +650,15 @@ class SemiSupervisedModel(BaseModel):
         if self.do_before_test:
             self.do_before_test(**kwargs)
 
-        loss, accuracy = self.do_forward(test_data, training=False)
+        loss, accuracy = self.test_step(test_data)
 
         return loss, accuracy
 
-    def do_forward(self, sequence, training=True):
+    def train_step(self, sequence):
         """
             Forward propagation for the input `sequence`. This method will be called 
-            in `train` and `test`, you can rewrite it for you customized training/testing 
-            process. If you want to specify your customized data during traing/testing/predicting, 
-            you can implement a sub-class of `graphgallery.NodeSequence`, wich is iterable 
+            in `train`. If you want to specify your customized data during traing/testing/predicting, 
+            you can implement a subclass of `graphgallery.NodeSequence`, wich is iterable 
             and yields `inputs` and `labels` in each iteration. 
 
 
@@ -480,8 +671,6 @@ class SemiSupervisedModel(BaseModel):
         ----------
             sequence: `graphgallery.NodeSequence`
                 The input `sequence`.    
-            trainng (Boolean, optional): 
-                Indicating training or test procedure. (default: :obj:`True`)
 
         Return:
         ----------
@@ -492,20 +681,49 @@ class SemiSupervisedModel(BaseModel):
 
         """
         model = self.model
-
-        if training:
-            forward_fn = model.train_on_batch
-        else:
-            forward_fn = model.test_on_batch
-
         model.reset_metrics()
 
         with tf.device(self.device):
             for inputs, labels in sequence:
-                loss, accuracy = forward_fn(x=inputs, y=labels, reset_metrics=False)
+                loss, accuracy = model.train_on_batch(x=inputs, y=labels, reset_metrics=False)
 
         return loss, accuracy
+    
+    def test_step(self, sequence):
+        """
+            Forward propagation for the input `sequence`. This method will be called 
+            in `test`. If you want to specify your customized data during traing/testing/predicting, 
+            you can implement a subclass of `graphgallery.NodeSequence`, wich is iterable 
+            and yields `inputs` and `labels` in each iteration. 
 
+
+        Note:
+        ----------
+            You must compile your model before training/testing/predicting. 
+            Use `model.build()`.
+
+        Arguments:
+        ----------
+            sequence: `graphgallery.NodeSequence`
+                The input `sequence`.    
+
+        Return:
+        ----------
+            loss: Float scalar
+                Output loss of forward propagation.
+            accuracy: Float scalar
+                Output accuracy of prediction.
+
+        """
+        model = self.model
+        model.reset_metrics()
+
+        with tf.device(self.device):
+            for inputs, labels in sequence:
+                loss, accuracy = model.test_on_batch(x=inputs, y=labels, reset_metrics=False)
+
+        return loss, accuracy
+    
     def predict(self, index, **kwargs):
         """
             Predict the output probability for the `index` of nodes.
@@ -583,19 +801,19 @@ class SemiSupervisedModel(BaseModel):
     def __call__(self, inputs):
         return self.model(inputs)
 
-    @property
-    def weights(self):
-        """Return the weights of model, type `tf.Tensor`."""
-        return self.model.weights
+#     @property
+#     def weights(self):
+#         """Return the weights of model, type `tf.Tensor`."""
+#         return self.model.weights
 
-    def get_weights(self):
-        """Return the weights of model, type Numpy array-like."""
-        return self.model.get_weights()
+#     def get_weights(self):
+#         """Return the weights of model, type Numpy array-like."""
+#         return self.model.get_weights()
 
-    @property
-    def trainable_variables(self):
-        """Return the trainable weights of model, type `tf.Tensor`."""
-        return self.model.trainable_variables
+#     @property
+#     def trainable_variables(self):
+#         """Return the trainable weights of model, type `tf.Tensor`."""
+#         return self.model.trainable_variables
 
     def reset_weights(self):
         """reset the model to the first time.
