@@ -10,8 +10,8 @@ from graphgallery import Bunch
 class Deepwalk(UnsupervisedModel):
     """
         Implementation of DeepWalk Unsupervised Graph Neural Networks (DeepWalk). 
-        [DeepWalk: Online Learning of Social Representations](https://arxiv.org/abs/1403.6652)
-        Implementation: https://github.com/phanein/deepwalk
+        `DeepWalk: Online Learning of Social Representations <https://arxiv.org/abs/1403.6652>`
+        Implementation: <https://github.com/phanein/deepwalk>
 
         Arguments:
         ----------
@@ -19,9 +19,6 @@ class Deepwalk(UnsupervisedModel):
                 Numpy array-like (or matrix) if `is_adj_sparse=False`.
                 The input `symmetric` adjacency matrix, where `N` is the number 
                 of nodes in graph.
-            x: shape (N, F), Scipy sparse matrix if `is_x_sparse=True`, 
-                Numpy array-like (or matrix) if `is_x_sparse=False`.
-                The input node feature matrix, where `F` is the dimension of features.
             labels: Numpy array-like with shape (N,)
                 The ground-truth labels for all nodes in graph.
             device (String, optional): 
@@ -36,9 +33,9 @@ class Deepwalk(UnsupervisedModel):
 
     """
 
-    def __init__(self, adj, x, labels, device='CPU:0', seed=None, name=None, **kwargs):
+    def __init__(self, adj, labels, device='CPU:0', seed=None, name=None, **kwargs):
 
-        super().__init__(adj, x, labels, device=device, seed=seed, name=name, **kwargs)
+        super().__init__(adj, labels=labels, device=device, seed=seed, name=name, **kwargs)
 
     def build(self, walk_length=80, walks_per_node=10,
               embedding_dim=64, window_size=5, workers=16,
