@@ -1,4 +1,4 @@
 from graphgallery.utils.history import History
 from graphgallery.utils.data_utils import Bunch, sample_mask, normalize_adj, normalize_x
-from graphgallery.utils.shape_utils import set_equal_in_length, get_length
+from graphgallery.utils.shape import set_equal_in_length, get_length
 from graphgallery.utils.probar import progress_bar
