@@ -19,7 +19,7 @@ def check_and_convert(matrix, is_sparse):
 
     Arguments:
     ----------
-        matrix: Scipy sparse matrix or Numpy array-like or Numpy matrix.
+        matrix: Scipy sparse matrix or Numpy array-like or Numpy matrix or None.
         is_sparse: Indicating whether the input matrix is sparse matrix or not.
 
     Returns:
@@ -29,11 +29,14 @@ def check_and_convert(matrix, is_sparse):
     """
     if is_list_like(matrix):
         return [check_and_convert(m, is_sparse) for m in matrix]
-
+    
+    if matrix is None:
+        return matrix
+    
     if not is_sparse:
         if not isinstance(matrix, (np.ndarray, np.matrix)):
             raise TypeError("The input matrix must be Numpy array-like or Numpy matrix"
-                            f" when `is_sparse=False`, but got {type(x)}")
+                            f" when `is_sparse=False`, but got {type(matrix)}")
         return np.asarray(matrix, dtype=config.floatx())
     else:
         if not sp.issparse(matrix):
@@ -118,9 +121,9 @@ def infer_type(x):
     if not hasattr(x, 'dtype'):
         x = np.asarray(x)
 
-    if x.dtype.kind == 'f':
+    if x.dtype.kind in {'f', 'c'}:
         return config.floatx()
-    elif x.dtype.kind == 'i' or x.dtype.kind == 'u':
+    elif x.dtype.kind in {'i', 'u'}:
         return config.intx()
     elif x.dtype.kind == 'b':
         return 'bool'
@@ -188,7 +191,7 @@ def astensor(x, dtype=None):
     elif sp.isspmatrix(x):
         return sparse_adj_to_sparse_tensor(x.astype(dtype, copy=False))
     elif isinstance(x, (np.ndarray, np.matrix)) or is_list_like(x) or is_scalar_like(x):
-        return tf.convert_to_tensor(x, dtype=infer_type(x))
+        return tf.convert_to_tensor(x, dtype=dtype)
     else:
         raise TypeError(f'Invalid type of inputs data. Allowed data type `(Tensor, SparseTensor, Numpy array, Scipy sparse tensor, None)`, but got {type(x)}.')
 
